/***********************************************************************************************************************
 *
 * blueBill Core - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it
 * SCM: https://kenai.com/hg/bluebill~core-src
 *
 **********************************************************************************************************************/
package it.tidalwave.observation;

import javax.annotation.Nonnull;
import java.io.Serializable;
import org.openide.util.Lookup;
import it.tidalwave.util.As;

/***********************************************************************************************************************
 *
 * Represents a single item of an {@link Observation}, targeting an {@link Observable} with a {@link Cardinality}. 
 *
 * @stereotype Datum
 * @composed "*" - "1" Observable
 * @composed "1" - "0..*" TextNote
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 * 
 **********************************************************************************************************************/
public interface ObservationItem extends Lookup.Provider, As, Serializable
  {
    /*******************************************************************************************************************
     *
     * Returns the {@link Observable} that is the target of this
     * {@code ObservationItem}.
     *
     * @return  the {@code Observable}
     *
     ******************************************************************************************************************/
    @Nonnull
    public Observable getObservable();

    /*******************************************************************************************************************
     *
     * Returns the {@link Cardinality} of this {@code ObservationItem}.
     *
     * @return  the {@code Cardinality}
     *
     ******************************************************************************************************************/
    @Nonnull
    public Cardinality getCardinality();

    /*******************************************************************************************************************
     *
     * Returns the {@link Observation} that contains this {@code ObservationItem}.
     *
     * @return  the {@code Cardinality}
     *
     ******************************************************************************************************************/
    @Nonnull
    public Observation getObservation();
  }
