/***********************************************************************************************************************
 *
 * blueBill Core - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it
 * SCM: https://kenai.com/hg/bluebill~core-src
 *
 **********************************************************************************************************************/
package it.tidalwave.observation;

import javax.annotation.Nonnull;
import it.tidalwave.util.Id;

/***********************************************************************************************************************
 *
 * A manager for creating and retrieving {@link ObservationSet}s.
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 * @stereotype Role
 * @composed "1" "<create>\n<find>" "0..*" ObservationSet
 * 
 **********************************************************************************************************************/
public interface ObservationManager
  {
    /*******************************************************************************************************************
     *
     * Creates a new, transient {@link ObservationSet} stored in memory.
     *
     * @return  the {@code ObservationSet}
     *
     ******************************************************************************************************************/
    @Nonnull
    public ObservationSet createObservationSet();

    /*******************************************************************************************************************
     *
     * Creates an object representing a persistent {@link ObservationSet} stored
     * in the given repository.
     *
     * @param   repository  the repository
     * @return              the {@code ObservationSet}
     *
     ******************************************************************************************************************/
    @Nonnull
    public ObservationSet createObservationSet (@Nonnull Object repository);

    @Nonnull
    public ObservationSet findOrCreateObservationSetById (@Nonnull Id id);
  }
