/***********************************************************************************************************************
 *
 * blueBill Core - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it
 * SCM: https://kenai.com/hg/bluebill~core-src
 *
 **********************************************************************************************************************/
package it.tidalwave.observation.spi;

import javax.annotation.Nonnull;
import it.tidalwave.observation.Observation;
import it.tidalwave.observation.ObservationItem;
import it.tidalwave.observation.ObservationSet;
import it.tidalwave.observation.ObservationVisitor;
import it.tidalwave.observation.ObservationSetTraverser;
import static it.tidalwave.observation.Observation.Observation;

/***********************************************************************************************************************
 *
 * A default implementation of {@link ObservationSetTraverser}.
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class DefaultObservationSetTraverser implements ObservationSetTraverser
  {
    @Nonnull
    private final ObservationSet observationSet;

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    public DefaultObservationSetTraverser (final @Nonnull ObservationSet observationSet)
      {
        this.observationSet = observationSet;
      }

    /*******************************************************************************************************************
     *
     * {@inheritDoc}
     *
     ******************************************************************************************************************/
    @Nonnull
    public <T extends ObservationVisitor> T accept (final @Nonnull T visitor)
      {
        visitor.preVisit(observationSet);
        visitor.visit(observationSet);

        for (final Observation observation : observationSet.find(Observation).results())
          {
            visitor.preVisit(observation);
            visitor.visit(observation);

            for (final ObservationItem item : observation.findObservationItems().results())
              {
                visitor.visit(item);
              }

            visitor.postVisit(observation);
          }

        visitor.postVisit(observationSet);
        
        return visitor;
      }
  }
